summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
Diffstat (limited to 'lib')
-rw-r--r--lib/irb.rb2
-rw-r--r--lib/irb/ext/eval_history.rb (renamed from lib/irb/ext/history.rb)8
-rw-r--r--lib/irb/extend-command.rb2
3 files changed, 6 insertions, 6 deletions
diff --git a/lib/irb.rb b/lib/irb.rb
index 64c716fd4c..1f86a0f386 100644
--- a/lib/irb.rb
+++ b/lib/irb.rb
@@ -154,7 +154,7 @@ require_relative "irb/easter-egg"
#
# IRB.conf[:EVAL_HISTORY] = <number>
#
-# See IRB::Context#eval_history= and History class. The history of command
+# See IRB::Context#eval_history= and EvalHistory class. The history of command
# results is not permanently saved in any file.
#
# == Customizing the IRB Prompt
diff --git a/lib/irb/extend-command.rb b/lib/irb/extend-command.rb
index 7238f1fd1c..514293a438 100644
--- a/lib/irb/extend-command.rb
+++ b/lib/irb/extend-command.rb
@@ -316,7 +316,7 @@ module IRB # :nodoc:
CE = ContextExtender # :nodoc:
@EXTEND_COMMANDS = [
- [:eval_history=, "ext/history.rb"],
+ [:eval_history=, "ext/eval_history.rb"],
[:use_tracer=, "ext/tracer.rb"],
[:use_loader=, "ext/use-loader.rb"],
]
diff --git a/lib/irb/ext/history.rb b/lib/irb/ext/eval_history.rb
index 5243504efa..1a04178b40 100644
--- a/lib/irb/ext/history.rb
+++ b/lib/irb/ext/eval_history.rb
@@ -40,14 +40,14 @@ module IRB # :nodoc:
#
# If +no+ is +nil+, execution result history isn't used (default).
#
# History values are available via <code>__</code> variable, see
# IRB::History.
def eval_history=(no)
if no
if defined?(@eval_history) && @eval_history
@eval_history_values.size(no)
else
- @eval_history_values = History.new(no)
+ @eval_history_values = EvalHistory.new(no)
IRB.conf[:__TMP__EHV__] = @eval_history_values
@workspace.evaluate("__ = IRB.conf[:__TMP__EHV__]")
IRB.conf.delete(:__TMP_EHV__)
@@ -89,7 +89,7 @@ module IRB # :nodoc:
# __[1]
# # => 10
#
- class History
+ class EvalHistory
def initialize(size = 16) # :nodoc:
@size = size
@@ -40,14 +40,14 @@ module IRB # :nodoc:
# If +no+ is +nil+, execution result history isn't used (default).
#
- # History values are available via <code>__</code> variable, see
- # IRB::History.
+ # EvalHistory values are available via <code>__</code> variable, see
+ # IRB::EvalHistory.
def eval_history=(no)
if no